pub struct OutputLine {
pub run_id: RunId,
pub stream: OutputStream,
pub line: String,
pub seq: u64,
pub id: OutputLineId,
}Fields
run_id: RunIdstream: OutputStreamline: Stringseq: u64id: OutputLineIdTrait Implementations
Sourceimpl AnyItem for OutputLine
impl AnyItem for OutputLine
Sourcefn entity_type(&self) -> &'static str
fn entity_type(&self) -> &'static str
Returns the entity type name (e.g., “Target”, “Scene”).
Sourcefn server_owner(&self) -> Option<&str>
fn server_owner(&self) -> Option<&str>
Returns the current
#[server_owned] field value, if this item has one.Sourceimpl Clone for OutputLine
impl Clone for OutputLine
Sourcefn clone(&self) -> OutputLine
fn clone(&self) -> OutputLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputLine
impl Debug for OutputLine
Sourceimpl<'de> Deserialize<'de> for OutputLine
impl<'de> Deserialize<'de> for OutputLine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Eventable for OutputLine
impl Eventable for OutputLine
Sourceconst ENTITY_NAME_STATIC: &'static str = "OutputLine"
const ENTITY_NAME_STATIC: &'static str = "OutputLine"
Static entity type name (use
entity_type() from AnyItem for instance access).Sourcefn entity_name_static() -> &'static str
fn entity_name_static() -> &'static str
Back-compat helper for generic call sites that still expect a function.
Sourcefn ingest_buffer_policy() -> IngestBufferPolicy
fn ingest_buffer_policy() -> IngestBufferPolicy
Opt-in ingest buffering policy for this entity type.
Sourceimpl IdFor<OutputLine> for OutputLineId
impl IdFor<OutputLine> for OutputLineId
Sourceimpl Partial for OutputLine
impl Partial for OutputLine
Sourcetype Item = PartialOutputLine
type Item = PartialOutputLine
The type of the partial structure, that may have
Some values.Sourcefn apply_some(&mut self, partial: Self::Item) -> bool
fn apply_some(&mut self, partial: Self::Item) -> bool
Applies
Some values from Partial::Item to self, returning true when
updates were made, and false when nothing was applied. Read moreSourceimpl PartialEq for OutputLine
impl PartialEq for OutputLine
Sourceimpl Serialize for OutputLine
impl Serialize for OutputLine
impl StructuralPartialEq for OutputLine
Sourceimpl TS for OutputLine
impl TS for OutputLine
Sourcetype WithoutGenerics = OutputLine
type WithoutGenerics = OutputLine
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = OutputLine
type OptionInnerType = OutputLine
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
Sourceimpl WithTypedId for OutputLine
impl WithTypedId for OutputLine